# Example to illustrate the use of EkNNclus (similar to example 2 in the paper)
# 14 March, 2016

# Generation of the data
n<-60
s<-0.01
x<-rbind(mvrnorm(n = n/3, mu=c(0,1), Sigma=s*diag(2)),
         mvrnorm(n = n/3, mu=c(1,1), Sigma=s*diag(2)),
         mvrnorm(n = n/3, mu=c(0.5,0), Sigma=s*diag(2)))
r<-10
x1<-matrix(-1+3*runif(r*2),r,2)
x<-rbind(x,x1)
# Plot of the data
plot(x[,1],x[,2])
n<-dim(x)[1]

# Clustering

y0<-1:n # intial partition
K<-30 # number of neighbors
N<-5 # number of trials

cl<- EkNNclus(x,K=30,y0=(1:n),N=N,q=0.5,sym=FALSE,p=2,disp=TRUE,tr=TRUE,cred=TRUE)
c<-max(cl$y)

# Plot of the partition (Figure 2a in the paper)
plot(x[,1],x[,2],pch=cl$y)

# Plot of cost function vs number of iteration (Figure 3 in the paper)
L<-vector(length=N)
for(i in 1:N) L[i]<-dim(cl$trace[cl$trace[,1]==i,])[1]
imax<-which.max(L)
plot(0:(L[imax]-1),-cl$trace[cl$trace[,1]==imax,3],type="l",lty=imax,xlab="time steps",ylab="energy")
for(i in (1:N)) if(i != imax) lines(0:(L[i]-1),-cl$trace[cl$trace[,1]==i,3],type="l",lty=i)
